
# Slot: object




URI: [biolink:gene_to_gene_product_relationship_object](https://w3id.org/biolink/vocab/gene_to_gene_product_relationship_object)

## Domain and Range

[GeneToGeneProductRelationship](GeneToGeneProductRelationship.md) ->  <sub>REQ</sub> [GeneProduct](GeneProduct.md)

## Parents

 *  is_a: [object](sequence_feature_relationship_object.md)

## Children


## Used by

 * [GeneToGeneProductRelationship](GeneToGeneProductRelationship.md)
